@@ -16,6 +16,7 @@ from .BibFilter import BibFilter
 from .BibjsonCard import BibjsonCard
 from .BibtexButton import BibtexButton
 from .CrossrefCard import CrossrefCard
+from .DataBlock import DataBlock
 from .DownloadButton import DownloadButton
 from .DownloadDropdown import DownloadDropdown
 from .GlobalSearchBar import GlobalSearchBar
@@ -23,6 +24,7 @@ from .MaterialsInput import MaterialsInput
 from .OpenAccessButton import OpenAccessButton
 from .SearchUI import SearchUI
 from .Select import Select
+from .Tooltip import Tooltip
 
 __all__ = [
     "JsonView",
@@ -43,11 +45,13 @@ __all__ = [
     "BibjsonCard",
     "BibtexButton",
     "CrossrefCard",
+    "DataBlock",
     "DownloadButton",
     "DownloadDropdown",
     "GlobalSearchBar",
     "MaterialsInput",
     "OpenAccessButton",
     "SearchUI",
-    "Select"
+    "Select",
+    "Tooltip"
 ]
\ No newline at end of file
